@@ -167,6 +167,7 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 		applyArgs.module,
 		version,
 		tmpDir,
+		rootArgs.cacheDir,
 		applyArgs.creds.String(),
 	)
 	mod, err := fetcher.Fetch()
@@ -214,10 +215,10 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 
 	buildResult, err := builder.Build()
 	if err != nil {
-		return describeErr(fetcher.GetModuleRoot(), "failed to build instance", err)
+		return describeErr(fetcher.GetModuleRoot(), "build failed", err)
 	}
 
-	finalValues, err := builder.GetValues(buildResult)
+	finalValues, err := builder.GetDefaultValues()
 	if err != nil {
 		return fmt.Errorf("failed to extract values: %w", err)
 	}
@@ -326,6 +327,10 @@ func runApplyCmd(cmd *cobra.Command, args []string) error {
 		}
 	}
 
+	if images, err := builder.GetContainerImages(buildResult); err == nil {
+		im.Instance.Images = images
+	}
+
 	if err := sm.Apply(ctx, &im.Instance, true); err != nil {
 		return fmt.Errorf("storing instance failed: %w", err)
 	}
