@@ -234,6 +234,7 @@ func fetchBundleInstanceModule(ctx context.Context, instance *engine.BundleInsta
 		instance.Module.Repository,
 		moduleVersion,
 		modDir,
+		rootArgs.cacheDir,
 		bundleApplyArgs.creds.String(),
 	)
 	mod, err := fetcher.Fetch()
@@ -283,10 +284,10 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance *eng
 
 	buildResult, err := builder.Build()
 	if err != nil {
-		return describeErr(modDir, "failed to build instance", err)
+		return describeErr(modDir, "build failed for "+instance.Name, err)
 	}
 
-	finalValues, err := builder.GetValues(buildResult)
+	finalValues, err := builder.GetDefaultValues()
 	if err != nil {
 		return fmt.Errorf("failed to extract values: %w", err)
 	}
@@ -405,6 +406,10 @@ func applyBundleInstance(ctx context.Context, cuectx *cue.Context, instance *eng
 		}
 	}
 
+	if images, err := builder.GetContainerImages(buildResult); err == nil {
+		im.Instance.Images = images
+	}
+
 	if err := sm.Apply(ctx, &im.Instance, true); err != nil {
 		return fmt.Errorf("storing instance failed: %w", err)
 	}
