@@ -12,7 +12,6 @@ import (
 	"time"
 
 	"github.com/distribution/distribution/v3/configuration"
-	dcontext "github.com/distribution/distribution/v3/context"
 	"github.com/distribution/distribution/v3/registry"
 	_ "github.com/distribution/distribution/v3/registry/auth/htpasswd"
 	_ "github.com/distribution/distribution/v3/registry/storage/driver/inmemory"
@@ -75,6 +74,7 @@ func TestMain(m *testing.M) {
 	}
 
 	kubeconfigArgs.KubeConfig = &tmpFilename
+	rootArgs.cacheDir = tmpDir
 
 	code := m.Run()
 	testEnv.Stop()
@@ -120,15 +120,16 @@ func resetCmdArgs() {
 	applyArgs = applyFlags{}
 	buildArgs = buildFlags{}
 	deleteArgs = deleteFlags{}
+	statusArgs = statusFlags{}
 	inspectModuleArgs = inspectModuleFlags{}
 	inspectResourcesArgs = inspectResourcesFlags{}
 	inspectValuesArgs = inspectValuesFlags{}
-	lintModArgs = lintModFlags{}
+	vetModArgs = vetModFlags{}
 	listArgs = listFlags{}
 	pullModArgs = pullModFlags{}
 	pushModArgs = pushModFlags{}
 	bundleApplyArgs = bundleApplyFlags{}
-	bundleLintArgs = bundleLintFlags{}
+	bundleVetArgs = bundleVetFlags{}
 	bundleDelArgs = bundleDelFlags{}
 	bundleBuildArgs = bundleBuildFlags{}
 	vendorCrdArgs = vendorCrdFlags{}
@@ -151,14 +152,11 @@ func setupRegistryServer(ctx context.Context) error {
 	config := &configuration.Configuration{}
 	config.Log.AccessLog.Disabled = true
 	config.Log.Level = "error"
-	logger := logrus.New()
-	logger.SetOutput(io.Discard)
-	dcontext.SetDefaultLogger(logrus.NewEntry(logger))
 	port, err := freeport.GetFreePort()
 	if err != nil {
 		return fmt.Errorf("failed to get free port: %s", err)
 	}
-
+	logrus.SetOutput(io.Discard)
 	dockerRegistry = fmt.Sprintf("localhost:%d", port)
 	config.HTTP.Addr = fmt.Sprintf("127.0.0.1:%d", port)
 	config.HTTP.DrainTimeout = time.Duration(10) * time.Second
