@@ -20,6 +20,8 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"reflect"
+	"slices"
 
 	"cuelang.org/go/cue"
 	"cuelang.org/go/cue/ast"
@@ -140,8 +142,10 @@ func (b *ModuleBuilder) SetVersionInfo(moduleVersion, kubeVersion string) {
 	}
 }
 
-// Build builds a CUE instances for the specified package and returns the CUE value.
-func (b *ModuleBuilder) Build() (cue.Value, error) {
+// Build builds the Timoni instance for the specified module and returns its CUE value.
+// If the instance validation fails, the returned error may represent more than one error,
+// retrievable with errors.Errors.
+func (b *ModuleBuilder) Build(tags ...string) (cue.Value, error) {
 	var value cue.Value
 	cfg := &load.Config{
 		ModuleRoot: b.moduleRoot,
@@ -166,22 +170,37 @@ func (b *ModuleBuilder) Build() (cue.Value, error) {
 		},
 	}
 
-	ix := load.Instances([]string{}, cfg)
-	if len(ix) == 0 {
+	if len(tags) > 0 {
+		cfg.Tags = append(cfg.Tags, tags...)
+	}
+
+	modInstances := load.Instances([]string{}, cfg)
+	if len(modInstances) == 0 {
 		return value, fmt.Errorf("no instances found")
 	}
 
-	inst := ix[0]
-	if inst.Err != nil {
-		return value, fmt.Errorf("instance error: %w", inst.Err)
+	modInstance := modInstances[0]
+	if modInstance.Err != nil {
+		return value, fmt.Errorf("instance error: %w", modInstance.Err)
 	}
 
-	v := b.ctx.BuildInstance(inst)
-	if v.Err() != nil {
-		return value, v.Err()
+	modValue := b.ctx.BuildInstance(modInstance)
+	if modValue.Err() != nil {
+		return value, modValue.Err()
 	}
 
-	return v, nil
+	// Extract the Timoni instance from the build value.
+	instance := modValue.LookupPath(cue.ParsePath(apiv1.InstanceSelector.String()))
+	if instance.Err() != nil {
+		return modValue, fmt.Errorf("lookup %s failed: %w", apiv1.InstanceSelector, instance.Err())
+	}
+
+	// Validate the Timoni instance which should be concrete and final.
+	if err := instance.Validate(cue.Concrete(true), cue.Final()); err != nil {
+		return modValue, err
+	}
+
+	return modValue, nil
 }
 
 // GetAPIVersion returns the list of API version of the Timoni's CUE definition.
@@ -251,12 +270,37 @@ func (b *ModuleBuilder) GetModuleName() (string, error) {
 	return mod, nil
 }
 
-// GetValues extracts the values from the build result.
-func (b *ModuleBuilder) GetValues(value cue.Value) (string, error) {
-	expr := value.LookupPath(cue.ParsePath(apiv1.ValuesSelector.String()))
-	if expr.Err() != nil {
-		return "", fmt.Errorf("lookup %s failed: %w", apiv1.ValuesSelector, expr.Err())
+// GetContainerImages extracts the container images referenced in the instance config values.
+func (b *ModuleBuilder) GetContainerImages(value cue.Value) ([]string, error) {
+	cfgValues := value.LookupPath(cue.ParsePath(apiv1.ConfigValuesSelector.String()))
+	if cfgValues.Err() != nil {
+		return nil, fmt.Errorf("lookup %s failed: %w", apiv1.ConfigValuesSelector, cfgValues.Err())
 	}
 
-	return fmt.Sprintf("%v", expr.Eval()), nil
+	var images []string
+	imgExtract := func(v cue.Value) bool {
+		switch v.IncompleteKind() {
+		case cue.StructKind:
+			var img apiv1.ImageReference
+			imgVal := reflect.ValueOf(img)
+			for i := 0; i < imgVal.Type().NumField(); i++ {
+				if tag, ok := imgVal.Type().Field(i).Tag.Lookup("json"); ok {
+					if !v.LookupPath(cue.ParsePath(tag)).Exists() {
+						return true
+					}
+				}
+			}
+			if err := v.Decode(&img); err == nil {
+				images = append(images, img.Reference)
+			}
+		}
+		return true
+	}
+
+	cfgValues.Walk(imgExtract, nil)
+
+	images = slices.Compact(images)
+	slices.Sort(images)
+
+	return images, nil
 }
